<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Models\Student;
use App\Models\Assignment;
use App\Models\Submission;
use Illuminate\Http\Request;
use App\Models\Business_location;
use App\Models\Student_location;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;

class DashboardController extends Controller
{
    public function index()
    {
        $business_id = Auth::user()->business_id;
        $business_locations = Business_location::select(
            DB::raw('id'),
            DB::raw('business_name'),
            DB::raw('phone'),
            DB::raw('email'),
            DB::raw('owner_id'),
            DB::raw('license_start_date'),
            DB::raw('license_end_date'),
            DB::raw('is_active')
        )
        ->get();

        // Define Variables
        $total_business_locations = 0;
        $total_active_business_locations = 0;
        $total_inactive_business_locations = 0;
        $assignments = 0;
        $submissions = 0;
        $total_super_admins = 0;
        $total_owners = 0;
        $total_admins = 0;
        $total_trainers = 0;
        $students = 0;

        if (Auth::user()->role == 'super_admin') {
    
            $total_business_locations = $business_locations->count();
    
            $total_active_business_locations = $business_locations->where('is_active' , "Active")->count();
    
            $total_inactive_business_locations = $business_locations->where('is_active' , "InActive")->count();
    
            $assignments = Assignment::count();
    
            $submissions = Submission::count();
    
            $users = User::select(
                DB::raw('id'),
                DB::raw('role')
            )
            ->get();
    
            $total_super_admins = $users->where('role' , "super_admin")->count();
            $total_owners = $users->where('role' , "owner")->count();
            $total_admins = $users->where('role' , "admin")->count();
            $total_trainers = $users->where('role' , "trainer")->count();
    
            $students = Student::count();
        }
        else{
            
            // $total_business_locations = $business_locations->where('id' , $business_id)->count();
    
            // $total_active_business_locations = $business_locations->where('is_active' , "Active")->where('id' , $business_id)->count();
    
            // $total_inactive_business_locations = $business_locations->where('is_active' , "InActive")->where('id' , $business_id)->count();

            $assignments = Assignment::count();
    
            $submissions = Submission::where('business_id' , $business_id)->count();
    
            $users = User::select(
                DB::raw('id'),
                DB::raw('role')
            )
            ->get();
    
            $total_owners = $users->where('role' , "owner")
                                ->where('business_id' , $business_id)
                                ->count();
            $total_admins = $users->where('role' , "admin")
                                ->where('business_id' , $business_id)
                                ->count();
            $total_trainers = $users->where('role' , "trainer")
                                ->where('business_id' , $business_id)
                                ->count();
    
            $students = Student_location::where('business_id' , $business_id)->count();
        }

        // dd($students);

        return view('dashboard.index', [
                'total_business_locations' => $total_business_locations,
                'total_active_business_locations' => $total_active_business_locations,
                'total_inactive_business_locations' => $total_inactive_business_locations,
                'assignments' => $assignments,
                'submissions' => $submissions,
                'total_super_admins' => $total_super_admins,
                'total_owners' => $total_owners,
                'total_admins' => $total_admins,
                'total_trainers' => $total_trainers,
                'students' => $students,
                'business_locations' => $business_locations,
            ]);
    }

}